@@ -3,6 +3,7 @@ import json
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 from pydantic import ValidationError
 import traceback
+import threading
 
 from .utils import RuntimeError
 from .worker import Worker, WorkerSpec
@@ -51,6 +52,11 @@ class Executor:
         # logger.addHandler(fh)
         return logger
 
+    def heartbeat(self) -> None:
+        th = threading.Thread(target=self.worker.heartbeat)
+        th.daemon = True
+        th.start()
+
     def handle_request(self, task_id: str) -> int:
         """
         Returned status code should be passed to the used server implementation
